'use strict';
Object.defineProperty(exports, '__esModule', { value: true });
exports.SessionManager = void 0;
const zod_1 = require('zod');
const exceptions_1 = require('./exceptions');
const schemas_1 = require('./schemas');
const session_1 = require('./session');
class SessionManager {
  constructor(page) {
    this.page = page;
  }
  async dump(securityOrigin) {
    return session_1.getSessionData(this.page, securityOrigin);
  }
  async dumpString(securityOrigin) {
    return JSON.stringify(
      await session_1.getSessionData(this.page, securityOrigin),
    );
  }
  async restore(sessionData) {
    try {
      var data = schemas_1.SessionDataSchema.parse(sessionData);
    } catch (err) {
      if (err instanceof zod_1.ZodError) {
        throw new exceptions_1.CorruptedSessionDataError(err);
      }
      throw err;
    }
    await session_1.setSessionData(this.page, data);
  }
  async restoreString(sessionData) {
    await session_1.setSessionData(this.page, JSON.parse(sessionData));
  }
}
exports.SessionManager = SessionManager;
//# sourceMappingURL=manager.js.map
