'use strict';
var __importDefault =
  (this && this.__importDefault) ||
  function (mod) {
    return mod && mod.__esModule ? mod : { default: mod };
  };
Object.defineProperty(exports, '__esModule', { value: true });
const puppeteer_extra_1 = __importDefault(require('puppeteer-extra'));
const puppeteer_extra_plugin_stealth_1 = __importDefault(
  require('puppeteer-extra-plugin-stealth'),
);
const constants_1 = require('../../constants');
const plugin_1 = require('../../plugin');
jest.setTimeout(15000);
let browser;
let page;
puppeteer_extra_1.default
  .use(new plugin_1.SessionPlugin())
  .use(puppeteer_extra_plugin_stealth_1.default());
beforeAll(async () => {
  browser = await puppeteer_extra_1.default.launch({
    headless: true,
    executablePath: constants_1.TestBrowserExecutablePath,
  });
});
beforeEach(async () => {
  page = await browser.newPage();
  await page.goto('https://twitter.com/', { waitUntil: 'networkidle2' });
});
afterAll(async () => {
  await (browser === null || browser === void 0 ? void 0 : browser.close());
});
it('can get localdb', async () => {
  const session = await page.session.dump('https://twitter.com');
  // the db exist and was obtained
  expect(session.indexedDBDatabases).toHaveLength(1);
  expect(
    session.indexedDBDatabases.some((db) => db.name === 'localforage'),
  ).toBe(true);
});
it('can set indexDB', async () => {
  const session = await page.session.dump('https://twitter.com');
  expect(
    session.indexedDBDatabases.some((db) => db.name === 'localforage'),
  ).toBe(true);
  // Delete the database using CDP
  const client = await page.target().createCDPSession();
  await client.send('IndexedDB.deleteDatabase', {
    databaseName: 'localforage',
    securityOrigin: 'https://twitter.com',
  });
  await client.detach();
  // Dump the session again to make sure there is no localforage
  const emptySession = await page.session.dump('https://twitter.com');
  expect(
    emptySession.indexedDBDatabases.some((db) => db.name === 'localforage'),
  ).toBe(false);
  // Restore the indexedDB
  await page.session.restore(session);
  // Check to make sure the db was restored
  const finalSession = await page.session.dump('https://twitter.com');
  expect(
    finalSession.indexedDBDatabases.some((db) => db.name === 'localforage'),
  ).toBe(true);
});
//# sourceMappingURL=indexedDB.spec.js.map
